@@ -70,7 +70,7 @@ public:
     /**
      * Deletes the Ghost instance.
      */
-    ~Ghost();
+    ~Ghost() override;
 
     /**
      * Updates the Ghost move.
@@ -135,7 +135,7 @@ private:
      */
     void goLeft() override;
 
-signals:
+Q_SIGNALS:
 
     /**
      * Emitted when the Kapman has lost a life.
