@@ -58,9 +58,9 @@ public:
     /**
      * Deletes the KapmanItem instance.
      */
-    ~KapmanItem();
+    ~KapmanItem() override;
 
-public slots:
+public Q_SLOTS:
 
     /**
      * Rotates the image function of the Kapman direction.
